Frequently Asked Questions — ASE documentation

### Navigation

- index
- modules |

# Frequently Asked Questions

## ASE-GUI

See also the `documentation for ase-gui`.

### How do I export images from a trajectory to png or pov files?

With ase-gui, you can choose File ‣ Save, but this is not fun if you need to do it for many images. Here is how to do it on the command line for a number of images:

    ase-gui images.traj@0 -o image0.pov
    ase-gui images.traj@1 -o image1.pov
    ase-gui images.traj@2 -o image2.pov

If you have many images, it will be easier to do it using the Python interpreter:

    >>> from ase import *
    >>> for n, image in enumerate(read('images.traj@:3')):
    ...     write('image%d.pov' % n, image, run_povray=True, pause=False,
    ...           rotation='-90x,10z')

Here, we also:

- run povray to generate png files
- disable pausing between the images
- set a rotation (choose View ‣ Rotate ... in ase-gui to select the best rotation angles)

Try:

    >>> help(write)

to see all possibilities or read more `here`.

## General

### Citation: how should I cite ASE?

If you find ASE useful in your research please cite:

> S. R. Bahn and K. W. Jacobsen
> An object-oriented scripting interface to a legacy electronic structure code
> Comput. Sci. Eng., Vol. 4, 56-66, 2002

BibTex (doc/ASE.bib):

    @Article{ISI:000175131400009,
    Author = {S. R. Bahn and K. W. Jacobsen},
    Title = {An object-oriented scripting interface to a legacy electronic structure code},
    JournalFull = {COMPUTING IN SCIENCE \& ENGINEERING},
    Year = {2002},
    Volume = {4},
    Number = {3},
    Pages = {56-66},
    Month = {MAY-JUN},
    Abstract = {The authors have created an object-oriented scripting interface to a mature density functional theory
    code. The interface gives users a high-level, flexible handle on the code without rewriting the
    underlying number-crunching code. The authors also discuss the design issues and advantages of
    homogeneous interfaces},
    Publisher = {IEEE COMPUTER SOC},
    Address = {10662 LOS VAQUEROS CIRCLE, PO BOX 3014, LOS ALAMITOS, CA 90720-1314 USA},
    Type = {Article},
    Language = {English},
    Affiliation = {Bahn, SR (Reprint Author), Tech Univ Denmark, Dept Phys, CAMP, Bldg 307, DK-2800 Lyngby, Denmark.
    Tech Univ Denmark, Dept Phys, CAMP, DK-2800 Lyngby, Denmark.},
    ISSN = {1521-9615},
    Keywords-Plus = {MULTISCALE SIMULATION; GOLD ATOMS},
    Subject-Category = {Computer Science, Interdisciplinary Applications},
    Author-Email = {bahn@fysik.dtu.dk kwj@fysik.dtu.dk},
    Number-of-Cited-References = {19},
    Journal-ISO = {Comput. Sci. Eng.},
    Journal = {Comput. Sci. Eng.},
    Doc-Delivery-Number = {543YL},
    Unique-ID = {ISI:000175131400009},
    DOI = {10.1109/5992.998641},
    }

## Download

Trying to checkout the code via SVN resulted:

    [~]$ svn checkout "https://svn.fysik.dtu.dk/projects/ase/trunk"
    svn: Unrecognized URL scheme 'https://svn.fysik.dtu.dk/projects/ase/trunk'

This error is diplayed in case the library ‘libsvn_ra_dav’ is missing on your system. The library is used by SVN, but is not installed by default.

### Navigation

- index
- modules |